# Contributing to this repository

## Getting started
If you are reading this it probably means you have decided to contribute to the project, which is great news!
Now, before you start there are some things you need to know:
- This project is completely written in Java and powered by Android.
- You should read the [code of conduct](CODE_OF_CONDUCT.md)
- Before submitting a new issue, check out the [existing issues](https://github.com/Benji377/SocyMusic/issues)
- Everyone can contribute! Just find your [way of contributing](#types-of-contributions-memo)

### Don't see your issue?
If you spot a new issue which we don't know about you can open a new one using one of the [templates](https://github.com/Benji377/SocyMusic/issues/new/choose)
**Note:** We are only a small team right now, so please be patient, it might take some time to get a reply

### Ready to make a change?
If you want to change something about the app you can fork the repo and start coding.
You might want to download [Android Studio](https://developer.android.com/guide/slices/getting-started) for this.

Fork using GitHub Desktop:
- [Getting started with GitHub Desktop](https://docs.github.com/en/desktop/installing-and-configuring-github-desktop/getting-started-with-github-desktop) will guide you through setting up Desktop.
- Once Desktop is set up, you can use it to [fork the repo](https://docs.github.com/en/desktop/contributing-and-collaborating-using-github-desktop/cloning-and-forking-repositories-from-github-desktop)!

Fork using the command line:
- [Fork the repo](https://docs.github.com/en/github/getting-started-with-github/fork-a-repo#fork-an-example-repository) so that you can make your changes without affecting the original project until you're ready to merge them.

Fork with [GitHub Codespaces](https://github.com/features/codespaces):
- [Fork, edit, and preview](https://docs.github.com/en/free-pro-team@latest/github/developing-online-with-codespaces/creating-a-codespace) using [GitHub Codespaces](https://github.com/features/codespaces) without having to install and run the project locally.

### Open a pull request
When you're done making changes and you'd like to propose them for review, use the [pull request template](#pull-request-template) to open your PR (pull request).

## Resource naming convention
When contributing to this project, it's important that we all try to code in the same style to simplify organisation and make it easier for everyone to understand the code and contribute. Thats why we have strict naming conventions.
We got ours from an [answer on Stackoverflow.](https://stackoverflow.com/a/39866695/14159914) It is very simple to follow and there is even an image that you can save on your desktop if you forget things easily.

![UbsBV](https://user-images.githubusercontent.com/50681275/125126668-b9969a00-e0fb-11eb-8a86-b5a0399f12ec.png)

### Submit your PR & get it reviewed
- Once you submit your PR, others from the SocyMusic dev team will review it with you.
- After that, we may have questions, check back on your PR to keep up with the conversation.
- Did you have an issue, like a merge conflict? Check out the [git tutorial](https://lab.github.com/githubtraining/managing-merge-conflicts) on how to resolve merge conflicts and other issues.

### Your PR is merged!
Congratulations! The whole SocyMusic community thanks you. :sparkles:
Once your PR is merged, you will be proudly listed as a contributor in the [contributor chart](https://github.com/Benji377/SocyMusic/graphs/contributors).

### Keep contributing to SocyMusic
Other than pull reuquests and issues there is still a large varaity of ways to contribute:

- [Types of contributions :memo:](#types-of-contributions-memo)
  - [:mega: Discussions](#mega-discussions)
  - [:beetle: Issues](#beetle-issues)
  - [:hammer_and_wrench: Pull requests](#hammer_and_wrench-pull-requests)
  - [:earth_asia: Translations](#earth_asia-translations)
- [Starting with an issue](#starting-with-an-issue)
  - [Labels](#labels)
- [Opening a pull request](#opening-a-pull-request)
- [Reviewing](#reviewing)
  - [Self review](#self-review)
  - [Pull request template](#pull-request-template)
  - [Suggested changes](#suggested-changes)

## Types of contributions :memo:
You can contribute to the SocyMusic in several ways. If you are a developer you can contribute by improving the code. If you are a designer you can design new backgrounds and images for the app to make it look cool and modern. As a writer you also have the possibility to contribute to the translations and [docs](https://benji377.github.io/SocyMusic/)

### :mega: Discussions
Discussions are very important since majority of the conversation happens there.
If you have some new ideas, need help with something or would like to submit new translations and designs for review, [Discussions](https://github.com/Benji377/SocyMusic/discussions) is the place for you.

### :beetle: Issues
Issues are important to help discover bugs and manage the improvement of the app. As mentioned above, currently we are only a small team and we can't always test every scenario. Therefore we sometimes don't notice some bugs or don't notice ways of improving the app.

### :hammer_and_wrench: Pull requests
A pull request is the best way to submit new features to the app. Please do notice that not all pull requests are guaranteed to be merged. We will always label everything accordingly and eventually review with you your pr.

### :earth_africa: Translations
The app is currently only available in English.
We do plan on releasing a German and Italian version in the future, but translations are a big project which we will definitely need help with.

### Starting with an issue
Contributing sometimes can be as simple as replying to an open issue. If you see someone that needs help and you know the answer, don't hesitate to help out, we will then review the issue and eventually close it.

### Labels
Right now we are using the default Github labels and not all of them are really that important.
Here are the most important ones you should know about:
- The [`help wanted` label](https://github.com/Benji377/SocyMusic/issues?q=is%3Aopen+is%3Aissue+label%3A%22help+wanted%22) is for problems or updates that anyone in the community can start working on.
- The [`good first issue` label](https://github.com/Benji377/SocyMusic/issues?q=is%3Aopen+is%3Aissue+label%3A%22good+first+issue%22) is for problems or updates we think are ideal for beginners.
- The [`question` label](https://github.com/Benji377/SocyMusic/issues?q=is%3Aopen+is%3Aissue+label%3Aquestion) is for problems or updates in the app that need further explanation to be processed.
- The [`invalid` label](https://github.com/Benji377/SocyMusic/issues?q=is%3Aopen+is%3Aissue+label%3Ainvalid) is for problems or updates in the app that will not be processed because the data is invalid. You can help by editing the issue.
- The [`bug` label](https://github.com/Benji377/SocyMusic/labels/bug) is for general issues about the app code

## Opening a pull request
You can use the GitHub user interface :pencil2: for some small changes, like fixing a typo or updating a readme. You can also fork the repo and then clone it locally, to view changes and run your tests on your machine.

## Reviewing
We (SocyMusic dev team) review every single PR. The purpose of reviews is to create the best content we can for people who use SocyMusic.
:yellow_heart: Reviews are always respectful, acknowledging that everyone did the best possible job with the knowledge they had at the time.  
:yellow_heart: Reviews discuss content, not the person who created it.  
:yellow_heart: Reviews are constructive and start conversation around feedback.

### Self review
You should always review your own PR first.
For content changes, make sure that you:
- [ ] Confirm that the changes meet the user experience and goals outlined in the content design plan (if there is one).
- [ ] Compare your pull request's source changes to staging to confirm that the output matches the source and that everything is rendering as expected. This helps spot issues like typos, content that doesn't follow the style guide, or content that isn't rendering due to versioning problems
- [ ] Review the content for technical accuracy.
- [ ] Check new or updated Liquid statements to confirm that versioning is correct.
- [ ] If there are any failing checks in your PR, troubleshoot them until they're all passing.

### Pull request template
When you open a pull request, you must fill out the "Ready for review" template before we can review your PR. This template helps reviewers understand your changes and the purpose of your pull request.

### Suggested changes
We may ask for changes to be made before a PR can be merged, either using [suggested changes](https://docs.github.com/en/github/collaborating-with-issues-and-pull-requests/incorporating-feedback-in-your-pull-request) or pull request comments. You can apply suggested changes directly through the UI. You can make any other changes in your fork, then commit them to your branch.

As you update your PR and apply changes, mark each conversation as [resolved](https://docs.github.com/en/github/collaborating-with-issues-and-pull-requests/commenting-on-a-pull-request#resolving-conversations).

